#include <WiFi.h>
#include <WebSocketsServer.h>
#include <ESP32Servo.h>

const char* ssid = "DreamzStonez";
const char* password = "WelcomeBBc";
WebSocketsServer webSocket = WebSocketsServer(8080);
Servo servoMotor;

void setup() {
  Serial.begin(115200);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.println("Connecting to WiFi...");
  }
  Serial.println("Connected to WiFi");

  servoMotor.attach(20); // Attach servo to pin 13 (adjust pin as needed)
  servoMotor.write(90); // Set initial position of servo (90 degrees)

  webSocket.begin();
  webSocket.onEvent(webSocketEvent);
  Serial.println("WebSocket server started");
}

void loop() {
  webSocket.loop();
}

void webSocketEvent(uint8_t num, WStype_t type, uint8_t * payload, size_t length) {
  switch(type) {
    case WStype_DISCONNECTED:
      Serial.printf("[%u] Disconnected!\n", num);
      break;
    case WStype_CONNECTED:
      {
        IPAddress ip = webSocket.remoteIP(num);
        Serial.printf("[%u] Connected from %d.%d.%d.%d\n", num, ip[0], ip[1], ip[2], ip[3]);
      }
      break;
    case WStype_TEXT:
      {
        Serial.printf("[%u] Received text: %s\n", num, payload);
        int angle = atoi((const char*)payload);
        if (angle >= 0 && angle <= 180) {
          servoMotor.write(angle);
          Serial.printf("Set servo angle to %d degrees\n", angle);
        } else {
          Serial.println("Invalid angle value. Angle must be between 0 and 180.");
        }
      }
      break;
  }
}
